@@ -11,7 +11,7 @@
 try:
     import yaml
     using_yaml=True
-except ImportError:
+except ImportError:                                     #pragma:nocover
     using_yaml=False
 
 import plugins
@@ -33,7 +33,7 @@ class YamlTestParser(SingletonPlugin):
         return repn
 
     def print_test_config(self, repn):
-        print repn
+        print repn                                      #pragma:nocover
 
     def enabled(self):
         return using_yaml
